# Stuart Macdonald
# sjmac@ku.edu


# NOTES
#
# 1. Make sure the directories exist in your system.
#
# 2. Get Additional file 3 from Harbison et al. (2013) via
#    https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3644253/bin/1471-2164-14-281-S3.xls
#    Extract the "Line", "Night sleep (min.)" and "Day sleep (min.)" columns, just
#    for males and save as dgrp.sleeptime.txt tab-delimited text file.
#
# 3. Use the BDSC website to convert BDSC 5-digit IDs (used in our experiments) to the
#    "RAL_*" IDs used in Harbison et al. (Only do this for the 25 lines for which we
#    collected sleep data, save as dgrp.codes.txt)






##########################################################################################
# SET directories
uberDir <- "/Users/sjm/Desktop/InbredOutbred_DGRP/"
dirSummary <- paste(uberDir,"SummaryData/",sep="")
dirAnalysis <- paste(uberDir,"AnalyzedData/",sep="")

# READ in Harbison data
harb <- read.table(paste(dirAnalysis,"dgrp.sleeptime.txt",sep=""),header=T)

# READ in our DGRP sleep data
macdon.D <- read.table(paste(dirSummary,"DarkSleepTime.txt",sep=""),header=T)
macdon.L <- read.table(paste(dirSummary,"LightSleepTime.txt",sep=""),header=T)

# READ in DGRP ID conversion file
# TRUNCATE the phenotype files to only contain these IDs
# GET all phenotype files in the same row order
id.conv <- read.table(paste(dirAnalysis,"dgrp.codes.txt",sep=""),header=T)

harb.trunc <- harb[match(harb[,"ID"],id.conv[,"RAL"],nomatch=0)!=0,]
harb.trunc <- harb.trunc[order(harb.trunc[,"ID"]),]

macdon.D.trunc <- macdon.D[match(rownames(macdon.D),id.conv[,"BDSC"],nomatch=0)!=0,]

		# > rownames(macdon.D.trunc)==id.conv[,"BDSC"]
		#  [1] TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE

rownames(macdon.D.trunc) <- id.conv[,"RAL"]
macdon.D.trunc <- macdon.D.trunc[order(rownames(macdon.D.trunc)),]

macdon.L.trunc <- macdon.L[match(rownames(macdon.L),id.conv[,"BDSC"],nomatch=0)!=0,]

		# > rownames(macdon.L.trunc)==id.conv[,"BDSC"]
		#  [1] TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE TRUE

rownames(macdon.L.trunc) <- id.conv[,"RAL"]
macdon.L.trunc <- macdon.L.trunc[order(rownames(macdon.L.trunc)),]



##########################################################################################
# GET correlations between Harbison and our data
cor.test(harb.trunc[,"night.sleep"],macdon.D.trunc[,"Mean"])
cor.test(harb.trunc[,"day.sleep"],macdon.L.trunc[,"Mean"])

		# > cor.test(harb.trunc[,"night.sleep"],macdon.D.trunc[,"Mean"])
		# 
		# 	Pearson's product-moment correlation
		# 
		# data:  harb.trunc[, "night.sleep"] and macdon.D.trunc[, "Mean"]
		# t = 4.8873, df = 22, p-value = 6.924e-05
		# alternative hypothesis: true correlation is not equal to 0
		# 95 percent confidence interval:
		#  0.4486810 0.8712985
		# sample estimates:
		#       cor 
		# 0.7214905 
		# 
		# > 
		# > cor.test(harb.trunc[,"day.sleep"],macdon.L.trunc[,"Mean"])
		# 
		# 	Pearson's product-moment correlation
		# 
		# data:  harb.trunc[, "day.sleep"] and macdon.L.trunc[, "Mean"]
		# t = 5.1834, df = 22, p-value = 3.383e-05
		# alternative hypothesis: true correlation is not equal to 0
		# 95 percent confidence interval:
		#  0.4823714 0.8812797
		# sample estimates:
		#       cor 
		# 0.7414848 
		#
		# BOTH correlations are positive and strong, as expected



##########################################################################################
# ARE the sets of means the same?
t.test(harb.trunc[,"night.sleep"],macdon.D.trunc[,"Mean"])
t.test(harb.trunc[,"day.sleep"],macdon.L.trunc[,"Mean"])

		# > t.test(harb.trunc[,"night.sleep"],macdon.D.trunc[,"Mean"])
		# 
		# 	Welch Two Sample t-test
		# 
		# data:  harb.trunc[, "night.sleep"] and macdon.D.trunc[, "Mean"]
		# t = 4.256, df = 33.88, p-value = 0.0001554
		# alternative hypothesis: true difference in means is not equal to 0
		# 95 percent confidence interval:
		#   80.19376 226.80615
		# sample estimates:
		# mean of x mean of y 
		#  558.0035  404.5036 
		# 
		# > t.test(harb.trunc[,"day.sleep"],macdon.L.trunc[,"Mean"])
		# 
		# 	Welch Two Sample t-test
		# 
		# data:  harb.trunc[, "day.sleep"] and macdon.L.trunc[, "Mean"]
		# t = 3.8459, df = 45.318, p-value = 0.0003729
		# alternative hypothesis: true difference in means is not equal to 0
		# 95 percent confidence interval:
		#   72.97221 233.37203
		# sample estimates:
		# mean of x mean of y 
		#  376.5935  223.4214 
		#
		# LOOKS LIKE in our hands the DGRP lines sleep a lot less long
		# than reported in the Harbison paper. True for both L and D sleep.









